=============
django-planet
=============

.. image:: https://badge.fury.io/py/django-planet.png
   :target: http://badge.fury.io/py/django-planet

.. image:: https://pypip.in/d/django-planet/badge.png
   :target: https://pypi.python.org/pypi/django-planet

.. image:: https://travis-ci.org/matagus/django-planet.png
   :alt: Build Status (by travis.ci)
   :target: https://travis-ci.org/matagus/django-planet

.. image:: https://coveralls.io/repos/matagus/django-planet/badge.png
   :target: https://coveralls.io/r/matagus/django-planet

.. image:: https://d2weczhvl823v0.cloudfront.net/matagus/django-planet/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

This is a generic application for Django projects aiming to provide a planet
feed aggregator app.

It is compatible with `Pinax <http://pinaxproject.com/>`_ and its themed using `Twitter Bootstrap <http://twitter.github.com/bootstrap/>`_
and `Wave-Grind pattern as background from subtlepatter.com <http://subtlepatterns.com/wave-grind/>`_.

Screenshots
===========

Post list
---------

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/latest-posts.png

Post view
---------

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/post-view.png

Tag view
--------

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/tag-view.png

INSTALLATION
============

    * For installation instructions, see `the docs <http://django-planet.readthedocs.org/>`_.

Contribute
==========

- `Issue Tracker <https://github.com/matagus/django-planet/issues>`_
- `Source Code <https://github.com/matagus/django-planet>`_

Support
=======

If you are having issues or questions, visit `our forum <https://groups.google.com/forum/#!forum/django-planet>`_
and feel free to ask. I'll be glad to help you.

License
=======

The project is licensed under the BSD license.

DEMO
----

There is a `simple demo django-planet <http://django-planet.com/>`.
